@@ -36,8 +36,8 @@ function(e1, e2)
     .Class <- "matrix"
     NextMethod(.Generic)
     } else {
-      tmp.e1 <- merge.xts(e1, e2, all=FALSE, retclass=FALSE, retside=c(TRUE,FALSE))
-      e2 <- merge.xts(e2, e1, all=FALSE, retclass=FALSE, retside=c(TRUE,FALSE))
+      tmp.e1 <- merge.xts(e1, e2, all=FALSE, retclass=FALSE, retside=c(TRUE,FALSE), check.names=FALSE)
+      e2 <- merge.xts(e2, e1, all=FALSE, retclass=FALSE, retside=c(TRUE,FALSE), check.names=FALSE)
       e1 <- tmp.e1
       .Class <- "matrix"
       NextMethod(.Generic)
